import 'package:flutter/material.dart';

import '../models/attachment_media_type_enum.dart';
import '../models/media_attachment.dart';
import '../screens/image_viewer_screen.dart';
import 'audio_video/av_control.dart';
import 'image_control.dart';

class MediaAttachmentViewerControl extends StatefulWidget {
  final List<MediaAttachment> attachments;
  final int index;

  const MediaAttachmentViewerControl({
    super.key,
    required this.attachments,
    required this.index,
  });

  @override
  State<MediaAttachmentViewerControl> createState() =>
      _MediaAttachmentViewerControlState();
}

class _MediaAttachmentViewerControlState
    extends State<MediaAttachmentViewerControl> {
  @override
  Widget build(BuildContext context) {
    final item = widget.attachments[widget.index];
    const width = 250.0;
    const height = 250.0;
    if (item.explicitType == AttachmentMediaType.video) {
      return AVControl(
        videoUrl: item.uri.toString(),
        width: width,
        height: height,
        description: item.description,
      );
    }
    if (item.explicitType != AttachmentMediaType.image) {
      return Text('${item.explicitType}: ${item.uri}');
    }

    return ImageControl(
      width: width,
      height: height,
      imageUrl: item.thumbnailUri.toString(),
      altText: item.description,
      onTap: () async {
        Navigator.push(context, MaterialPageRoute(builder: (context) {
          return ImageViewerScreen(
            attachments: widget.attachments,
            initialIndex: widget.index,
          );
        }));
      },
    );
  }
}
